<?php

namespace Drupal\libraries_provider\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Library configuration entity class.
 *
 * @ConfigEntityType(
 *   id = "library",
 *   label = @Translation("Library"),
 *   label_collection = @Translation("Libraries"),
 *   label_singular = @Translation("library"),
 *   label_plural = @Translation("libraries"),
 *   label_count = @PluralTranslation(
 *     singular = "@count library",
 *     plural = "@count libraries",
 *   ),
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   config_prefix = "library",
 *   config_export = {
 *     "id",
 *     "label",
 *     "enabled",
 *     "version",
 *     "source",
 *     "minified",
 *     "variant",
 *     "replaces",
 *   }
 * )
 */
class Library extends ConfigEntityBase {

  /**
   * The library machine name.
   *
   * @var string
   */
  protected $id;

  /**
   * The human-readable name of the library entity.
   *
   * @var string
   */
  protected $label;

  /**
   * The status of this library.
   *
   * This a different concept from the status of the config entity.
   *
   * @var bool
   */
  protected $enabled;

  /**
   * The library version.
   *
   * @var string
   */
  protected $version;

  /**
   * The source of this library.
   *
   * @var string
   */
  protected $source;

  /**
   * When to Serve the library minified.
   *
   * @var string
   */
  protected $minified;

  /**
   * The library variant used.
   *
   * @var string
   */
  protected $variant;

  /**
   * The libraries that this library replaces.
   *
   * @var array
   */
  protected $replaces;

  /**
   * {@inheritdoc}
   */
  public function isEnabled() {
    return (bool) $this->enabled;
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    parent::calculateDependencies();

    // Add a dependency for the extension that defines the library.
    list($extension,) = explode('__', $this->id);
    $type = \Drupal::service('module_handler')->moduleExists($extension) ? 'module' : 'theme';
    $this->addDependency($type, $extension);

    // Add a dependency for the the module that provides the source plugin.
    $definition = \Drupal::service('plugin.manager.library_source')->getDefinition($this->source);
    $this->addDependency('module', $definition['provider']);

    return $this;
  }

}
