<?php

namespace Drupal\libraries_provider;

use Drupal\Core\Asset\LibraryDiscoveryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Extension\ThemeHandlerInterface;

/**
 * Provides methods for querying library information.
 */
class LibrariesProviderManager {

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * The theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeHandlerInterface
   */
  protected $themeHandler;

  /**
   * The library discovery service.
   *
   * @var \Drupal\Core\Asset\LibraryDiscoveryInterface
   */
  protected $libraryDiscovery;

  /**
   * Constructs a new LibrariesProviderManager instance.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   * @param \Drupal\Core\Theme\ThemeHandlerInterface $themeHandler
   *   The theme manager.
   * @param \Drupal\Core\Asset\LibraryDiscoveryInterface $libraryDiscovery
   *   The library discovery service.
   */
  public function __construct(
    ModuleHandlerInterface $moduleHandler,
    ThemeHandlerInterface $themeHandler,
    LibraryDiscoveryInterface $libraryDiscovery
  ) {
    $this->moduleHandler = $moduleHandler;
    $this->themeHandler = $themeHandler;
    $this->libraryDiscovery = $libraryDiscovery;
  }

  /**
   * Gather all the libraries handled by this module.
   */
  public function getManagedLibraries() {
    $libraries = [];
    $extensions = array_merge(
      array_keys($this->moduleHandler->getModuleList()),
      array_keys($this->themeHandler->listInfo())
    );
    foreach ($extensions as $extension) {
      foreach ($this->libraryDiscovery->getLibrariesByExtension($extension) as $name => $library) {
        if (!empty($library['libraries_provider'])) {
          $library['libraries_provider']['extension'] = $extension;
          $libraries[$extension . '__' . $name] = $library;
        }
      }
    }
    return $libraries;
  }

}
